@@ -8,7 +8,7 @@ async fn sleep() {
     tokio::time::sleep(Duration::from_millis(100)).await;
 }
 
-fn setup() -> (TaskTree, StringReporter) {
+fn setup() -> (Arc<TaskTree>, StringReporter) {
     let string_reporter = StringReporter::new();
     let tt = TaskTree::new();
     tt.add_reporter(Arc::new(string_reporter.clone()));
@@ -40,8 +40,12 @@ async fn basic_events_test() -> Result<()> {
     snapshot!(
         s.to_string(),
         "
-[ ] root:test                                                   
-[ ] [ERR] root:test_with_data                                   
+[ ] | STARTING | root
+[ ] | STARTING | root:test
+[ ] | STARTING | [ERR] root:test_with_data
+[ ] | STARTING | root:test_3
+[ ] root:test
+[ ] [ERR] root:test_with_data
   |      float: 5.98
   |      hello: hi
   |      int: 5
@@ -54,7 +58,7 @@ async fn basic_events_test() -> Result<()> {
   |  
   |  Caused by:
   |      here is error msg
-[ ] root:test_3                                                 
+[ ] root:test_3
 
 "
     );
@@ -101,14 +105,18 @@ Caused by:
     snapshot!(
         s.to_string(),
         "
-[ ] [ERR] root:top_level:1_level:2_level                        
+[ ] | STARTING | root
+[ ] | STARTING | [ERR] root:top_level
+[ ] | STARTING | [ERR] root:top_level:1_level
+[ ] | STARTING | [ERR] root:top_level:1_level:2_level
+[ ] [ERR] root:top_level:1_level:2_level
   |
   |  [Task] 2_level
   |  
   |  
   |  Caused by:
   |      oh noes, this fails
-[ ] [ERR] root:top_level:1_level                                
+[ ] [ERR] root:top_level:1_level
   |      1_level_data: 9
   |
   |  [Task] 1_level
@@ -119,7 +127,7 @@ Caused by:
   |      0: [Task] 2_level
   |         
   |      1: oh noes, this fails
-[ ] [ERR] root:top_level                                        
+[ ] [ERR] root:top_level
   |      top_level_data: 5
   |
   |  [Task] top_level
@@ -165,14 +173,23 @@ async fn logger_data_test() -> Result<()> {
     snapshot!(
         s.to_string(),
         "
-[ ] root:t1:has_process_id                                      
+[ ] | STARTING | root
+[ ] | STARTING | root:t1
+[ ] | STARTING | root:t1:has_process_id
+[ ] | STARTING | root:t1:t2
+[ ] | STARTING | root:t1:t2:has_process_and_request_id
+[ ] | STARTING | root:t1:t2:t3
+[ ] | STARTING | root:t1:t2:t3:wont_print_request_id
+[ ] | STARTING | root:t1:t2:t3:t4
+[ ] | STARTING | root:t1:t2:t3:t4:wont_print_request_id
+[ ] root:t1:has_process_id
   |      process_id: 123
-[ ] root:t1:t2:has_process_and_request_id                       
+[ ] root:t1:t2:has_process_and_request_id
   |      process_id: 123
   |      request_id: 234
-[ ] root:t1:t2:t3:wont_print_request_id                         
+[ ] root:t1:t2:t3:wont_print_request_id
   |      process_id: 123
-[ ] root:t1:t2:t3:t4:wont_print_request_id                      
+[ ] root:t1:t2:t3:t4:wont_print_request_id
   |      process_id: 123
 
 "
@@ -197,7 +214,9 @@ async fn async_test() -> Result<()> {
     snapshot!(
         s.to_string(),
         "
-[ ] root:async_event                                            
+[ ] | STARTING | root
+[ ] | STARTING | root:async_event
+[ ] root:async_event
   |      async_data: 5
 
 "
